@@ -1,6 +1,6 @@
 
 tam_trim_increment <- function(increment, max.increment, trim_increment="cut",
-	trim_incr_factor = 2, eps = 1E-10)
+	trim_incr_factor = 2, eps = 1E-10, avoid_na=FALSE)
 {
 	abs_old_increment <- abs(max.increment)
 	abs_increment <- abs(increment)
@@ -13,5 +13,8 @@ tam_trim_increment <- function(increment, max.increment, trim_increment="cut",
         increment <- ifelse( abs_increment > abs_old_increment  , 
                              sign(increment) * max.increment , increment )	
 	}
+	if (avoid_na){
+		increment <- ifelse( is.na(increment) , 0 , increment )
+	}	
 	return(increment)
 }
\ No newline at end of file
